@@ -1,5 +1,5 @@
 /*
- * "$Id: lpd.c 11173 2013-07-23 12:31:34Z msweet $"
+ * "$Id: lpd.c 12005 2014-07-08 15:46:59Z msweet $"
  *
  *   Line Printer Daemon backend for CUPS.
  *
@@ -393,8 +393,8 @@ main(int  argc,				/* I - Number of command-line arguments (6 or 7) */
          */
 
          snmp_enabled = !value[0] || !_cups_strcasecmp(value, "on") ||
-                        _cups_strcasecmp(value, "yes") ||
-                        _cups_strcasecmp(value, "true");
+                        !_cups_strcasecmp(value, "yes") ||
+                        !_cups_strcasecmp(value, "true");
       }
       else if (!_cups_strcasecmp(name, "timeout"))
       {
@@ -707,7 +707,7 @@ lpd_queue(const char      *hostname,	/* I - Host to connect to */
     */
 
     fprintf(stderr, "DEBUG: Connecting to %s:%d for printer %s\n", hostname,
-            _httpAddrPort(&(addrlist->addr)), printer);
+            httpAddrPort(&(addrlist->addr)), printer);
     _cupsLangPrintFilter(stderr, "INFO", _("Connecting to printer."));
 
     for (lport = reserve == RESERVE_RFC1179 ? 732 : 1024, addr = addrlist,
@@ -889,7 +889,7 @@ lpd_queue(const char      *hostname,	/* I - Host to connect to */
 
     fprintf(stderr, "DEBUG: Connected to %s:%d (local port %d)...\n",
 	    httpAddrString(&(addr->addr), addrname, sizeof(addrname)),
-	    _httpAddrPort(&(addr->addr)), lport);
+	    httpAddrPort(&(addr->addr)), lport);
 
    /*
     * See if the printer supports SNMP...
@@ -1276,7 +1276,7 @@ rresvport_af(int *port,			/* IO - Port number to bind to */
     * Try binding the port to the socket; return if all is OK...
     */
 
-    if (!bind(fd, (struct sockaddr *)&addr, sizeof(addr)))
+    if (!bind(fd, (struct sockaddr *)&addr, httpAddrSize(&addr)))
       return (fd);
 
    /*
@@ -1331,5 +1331,5 @@ sigterm_handler(int sig)		/* I - Signal */
 
 
 /*
- * End of "$Id: lpd.c 11173 2013-07-23 12:31:34Z msweet $".
+ * End of "$Id: lpd.c 12005 2014-07-08 15:46:59Z msweet $".
  */
